{% load portlets_tags %}

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN"
    "http://www.w3.org/TR/REC-html40/loose.dtd">    
<html>
<head>
<title>{{ flatpage.title }}</title>
</head>
<body>
<table>
     <tr>
         <td>
             {% portlet_slot 'Left' flatpage %}
         </td>
         <td>
             {{ flatpage.content }}
         </td>
         <td>
             {% portlet_slot 'Right' flatpage %}
         </td>
     </tr>
</table>
</body>
</html>